package com.j256.simplemagic;

/**
 * Returned by the magic matching code in {@link MagicUtil#contentTypeOfFile(java.io.File)} and others.
 * 
 * @author graywatson
 */
public class ContentType {

	private final String name;
	private final String message;
	private final String mimeType;

	public ContentType(String name, String mimeType, String message) {
		this.name = name;
		this.mimeType = mimeType;
		this.message = message;
	}

	/**
	 * Returns the short name of the content type. Usually this is the first word of the first matching line from the
	 * magic file.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns the mime-type or null if none.
	 */
	public String getMimeType() {
		return mimeType;
	}

	/**
	 * Returns the full message as generated by the magic matching code. This should be similar to the output from the
	 * Unix file(1) command.
	 */
	public String getMessage() {
		return message;
	}

	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append(name);
		if (mimeType != null) {
			sb.append(", mime '").append(mimeType).append('\'');
		}
		sb.append(", msg '").append(message).append('\'');
		return sb.toString();
	}
}
